==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/HelmDependency.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @io.sundr.builder.annotations.Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmDependency{
  public HelmDependency() {
  }
  public HelmDependency(java.lang.String name,java.lang.String version,java.lang.String repository) {
    this.name = name;
    this.version = version;
    this.repository = repository;
  }
  private java.lang.String name;
  private java.lang.String version;
  private java.lang.String repository;
  public java.lang.String getName() {
    return this.name;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public java.lang.String getRepository() {
    return this.repository;
  }
  public static io.dekorate.helm.config.HelmDependencyBuilder newBuilder() {
    return new io.dekorate.helm.config.HelmDependencyBuilder();
  }
  public static io.dekorate.helm.config.HelmDependencyBuilder newBuilderFromDefaults() {
    return new io.dekorate.helm.config.HelmDependencyBuilder();
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmDependency that = (HelmDependency) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  version,  repository,  super.hashCode());
  }
  
}

==> helm-annotations-2.9.2-sources.jar: io/dekorate/helm/config/HelmDependency.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class HelmDependency{
  public HelmDependency() {
  }
  public HelmDependency(String name,java.lang.String alias,java.lang.String version,java.lang.String repository) {
    this.name = name;
    this.alias = alias;
    this.version = version;
    this.repository = repository;
  }
  private java.lang.String name;
  private java.lang.String alias;
  private java.lang.String version;
  private java.lang.String repository;
  public java.lang.String getName() {
    return this.name;
  }
  public java.lang.String getAlias() {
    return this.alias;
  }
  public java.lang.String getVersion() {
    return this.version;
  }
  public java.lang.String getRepository() {
    return this.repository;
  }
  public static HelmDependencyBuilder newBuilder() {
    return new HelmDependencyBuilder();
  }
  public static io.dekorate.helm.config.HelmDependencyBuilder newBuilderFromDefaults() {
    return new io.dekorate.helm.config.HelmDependencyBuilder();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HelmDependency that = (HelmDependency) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (alias != null ? !alias.equals(that.alias) :that.alias != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    if (repository != null ? !repository.equals(that.repository) :that.repository != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  alias,  version,  repository,  super.hashCode());
  }
  
}
